import { EscrowContract } from './Contract.js';
import { EndorseRouter } from '../routes/endorse.js';
import { EndorseData } from '../schema/index.js';
export declare class EndorseController {
    readonly _contract: EscrowContract;
    constructor(contract: EscrowContract);
    get API(): EndorseRouter;
    get cid(): string;
    get pubkey(): string;
    get data(): Promise<EndorseData | undefined>;
    get hash(): Promise<string>;
    get signer(): (message: import("@cmdcode/buff-utils").Bytes) => import("@cmdcode/buff-utils").Bytes;
    refresh(): Promise<{
        status: "draft" | "published" | "active" | "disputed" | "closed";
        updated_at: Date;
        contract_id: string;
        members: string[];
        revision: number;
        created_at: Date;
        claims: {
            pubkey: string;
            address: string;
            nonce: string;
            script: string[];
        }[];
        deposits: {
            value: bigint;
            txid: string;
            vout: number;
        }[];
        details: {
            value: bigint;
            admin: string;
            agent: string;
            refund: string;
            expiration: number;
            title: string;
            description?: string | undefined;
            terms?: string | undefined;
        };
        endorsements: {
            pubkey: string;
            hash: string;
            signature: string;
        }[];
        fees: {
            pubkey: string;
            value: bigint;
            address: string;
            script: string[];
        }[];
        meta: {
            block_id: string;
            open_txid?: string | undefined;
            close_txid?: string | undefined;
        };
        payments: {
            pubkey: string;
            value: bigint;
            address: string;
            script: string[];
        }[];
        profiles: {
            pubkey: string;
            nonce: string;
            alias: string;
            tags: [string, string | number | boolean | null][];
        }[];
        records: {
            pubkey: string;
            label: string;
            content: string;
        }[];
        scripts: {
            pubkey: string;
            script: string[];
            label: string;
        }[];
        session: {
            secret: string;
            pubkey?: string | undefined;
            nonce?: string | undefined;
            sighash?: string | undefined;
            txhex?: string | undefined;
            taptweak?: string | undefined;
        };
        signatures: {
            pubkey: string;
            hash: string;
            psig: string;
        }[];
        transactions: {
            type: "refund" | "claim" | "deposit" | "settlement";
            txid: string;
            txhex: string;
            confirmed: boolean;
            updated_at: Date;
        }[];
    }>;
    list(): Promise<EndorseData[]>;
    add(hash?: string): Promise<{
        pubkey: string;
        hash: string;
        signature: string;
    } | undefined>;
    remove(): Promise<{
        pubkey: string;
        hash: string;
        signature: string;
    } | undefined>;
}
//# sourceMappingURL=Endorse.d.ts.map