import { z } from 'zod';
export type ContractData = z.infer<typeof data>;
export type ContractCreate = z.infer<typeof create>;
declare const create: z.ZodObject<{
    value: z.ZodBigInt;
    agent: z.ZodOptional<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>>;
    refund: z.ZodString;
    expiration: z.ZodDefault<z.ZodNumber>;
    description: z.ZodOptional<z.ZodString>;
    terms: z.ZodOptional<z.ZodString>;
    title: z.ZodString;
    private: z.ZodDefault<z.ZodBoolean>;
    claims: z.ZodOptional<z.ZodArray<z.ZodObject<{
        address: z.ZodString;
        nonce: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
    }, "strip", z.ZodTypeAny, {
        address: string;
        nonce: string;
    }, {
        address: string;
        nonce: string;
    }>, "many">>;
    payments: z.ZodOptional<z.ZodArray<z.ZodObject<{
        address: z.ZodString;
        value: z.ZodBigInt;
    }, "strip", z.ZodTypeAny, {
        value: bigint;
        address: string;
    }, {
        value: bigint;
        address: string;
    }>, "many">>;
    profile: z.ZodOptional<z.ZodObject<{
        alias: z.ZodString;
        nonce: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
        tags: z.ZodArray<z.ZodTuple<[z.ZodString, z.ZodUnion<[z.ZodString, z.ZodNumber, z.ZodBoolean, z.ZodNull]>], null>, "many">;
    }, "strip", z.ZodTypeAny, {
        nonce: string;
        alias: string;
        tags: [string, string | number | boolean | null][];
    }, {
        nonce: string;
        alias: string;
        tags: [string, string | number | boolean | null][];
    }>>;
    records: z.ZodOptional<z.ZodArray<z.ZodObject<{
        label: z.ZodString;
        content: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        label: string;
        content: string;
    }, {
        label: string;
        content: string;
    }>, "many">>;
    scripts: z.ZodOptional<z.ZodArray<z.ZodObject<{
        label: z.ZodString;
        script: z.ZodArray<z.ZodString, "many">;
    }, "strip", z.ZodTypeAny, {
        script: string[];
        label: string;
    }, {
        script: string[];
        label: string;
    }>, "many">>;
}, "strip", z.ZodTypeAny, {
    value: bigint;
    refund: string;
    expiration: number;
    title: string;
    private: boolean;
    agent?: string | undefined;
    description?: string | undefined;
    terms?: string | undefined;
    claims?: {
        address: string;
        nonce: string;
    }[] | undefined;
    payments?: {
        value: bigint;
        address: string;
    }[] | undefined;
    profile?: {
        nonce: string;
        alias: string;
        tags: [string, string | number | boolean | null][];
    } | undefined;
    records?: {
        label: string;
        content: string;
    }[] | undefined;
    scripts?: {
        script: string[];
        label: string;
    }[] | undefined;
}, {
    value: bigint;
    refund: string;
    title: string;
    agent?: string | undefined;
    expiration?: number | undefined;
    description?: string | undefined;
    terms?: string | undefined;
    private?: boolean | undefined;
    claims?: {
        address: string;
        nonce: string;
    }[] | undefined;
    payments?: {
        value: bigint;
        address: string;
    }[] | undefined;
    profile?: {
        nonce: string;
        alias: string;
        tags: [string, string | number | boolean | null][];
    } | undefined;
    records?: {
        label: string;
        content: string;
    }[] | undefined;
    scripts?: {
        script: string[];
        label: string;
    }[] | undefined;
}>;
declare const data: z.ZodObject<{
    contract_id: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
    members: z.ZodArray<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, "many">;
    status: z.ZodEnum<["draft", "published", "active", "disputed", "closed"]>;
    revision: z.ZodNumber;
    created_at: z.ZodDate;
    updated_at: z.ZodDate;
    claims: z.ZodArray<z.ZodObject<{
        address: z.ZodString;
        nonce: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
        pubkey: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
        script: z.ZodArray<z.ZodString, "many">;
    }, "strip", z.ZodTypeAny, {
        pubkey: string;
        address: string;
        nonce: string;
        script: string[];
    }, {
        pubkey: string;
        address: string;
        nonce: string;
        script: string[];
    }>, "many">;
    deposits: z.ZodArray<z.ZodObject<{
        txid: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
        vout: z.ZodNumber;
        value: z.ZodBigInt;
    }, "strip", z.ZodTypeAny, {
        value: bigint;
        txid: string;
        vout: number;
    }, {
        value: bigint;
        txid: string;
        vout: number;
    }>, "many">;
    details: z.ZodObject<{
        admin: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
        agent: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
        refund: z.ZodString;
        expiration: z.ZodNumber;
        description: z.ZodOptional<z.ZodString>;
        terms: z.ZodOptional<z.ZodString>;
        title: z.ZodString;
        value: z.ZodBigInt;
    }, "strip", z.ZodTypeAny, {
        value: bigint;
        admin: string;
        agent: string;
        refund: string;
        expiration: number;
        title: string;
        description?: string | undefined;
        terms?: string | undefined;
    }, {
        value: bigint;
        admin: string;
        agent: string;
        refund: string;
        expiration: number;
        title: string;
        description?: string | undefined;
        terms?: string | undefined;
    }>;
    endorsements: z.ZodArray<z.ZodObject<{
        hash: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
        signature: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
        pubkey: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
    }, "strip", z.ZodTypeAny, {
        pubkey: string;
        hash: string;
        signature: string;
    }, {
        pubkey: string;
        hash: string;
        signature: string;
    }>, "many">;
    fees: z.ZodArray<z.ZodObject<{
        value: z.ZodBigInt;
        address: z.ZodString;
        pubkey: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
        script: z.ZodArray<z.ZodString, "many">;
    }, "strip", z.ZodTypeAny, {
        pubkey: string;
        value: bigint;
        address: string;
        script: string[];
    }, {
        pubkey: string;
        value: bigint;
        address: string;
        script: string[];
    }>, "many">;
    meta: z.ZodObject<{
        block_id: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
        open_txid: z.ZodOptional<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>>;
        close_txid: z.ZodOptional<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>>;
    }, "strip", z.ZodTypeAny, {
        block_id: string;
        open_txid?: string | undefined;
        close_txid?: string | undefined;
    }, {
        block_id: string;
        open_txid?: string | undefined;
        close_txid?: string | undefined;
    }>;
    payments: z.ZodArray<z.ZodObject<{
        value: z.ZodBigInt;
        address: z.ZodString;
        pubkey: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
        script: z.ZodArray<z.ZodString, "many">;
    }, "strip", z.ZodTypeAny, {
        pubkey: string;
        value: bigint;
        address: string;
        script: string[];
    }, {
        pubkey: string;
        value: bigint;
        address: string;
        script: string[];
    }>, "many">;
    profiles: z.ZodArray<z.ZodObject<{
        nonce: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
        alias: z.ZodString;
        tags: z.ZodArray<z.ZodTuple<[z.ZodString, z.ZodUnion<[z.ZodString, z.ZodNumber, z.ZodBoolean, z.ZodNull]>], null>, "many">;
        pubkey: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
    }, "strip", z.ZodTypeAny, {
        pubkey: string;
        nonce: string;
        alias: string;
        tags: [string, string | number | boolean | null][];
    }, {
        pubkey: string;
        nonce: string;
        alias: string;
        tags: [string, string | number | boolean | null][];
    }>, "many">;
    records: z.ZodArray<z.ZodObject<{
        label: z.ZodString;
        content: z.ZodString;
        pubkey: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
    }, "strip", z.ZodTypeAny, {
        pubkey: string;
        label: string;
        content: string;
    }, {
        pubkey: string;
        label: string;
        content: string;
    }>, "many">;
    scripts: z.ZodArray<z.ZodObject<{
        script: z.ZodArray<z.ZodString, "many">;
        label: z.ZodString;
        pubkey: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
    }, "strip", z.ZodTypeAny, {
        pubkey: string;
        script: string[];
        label: string;
    }, {
        pubkey: string;
        script: string[];
        label: string;
    }>, "many">;
    session: z.ZodObject<{
        secret: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
        pubkey: z.ZodOptional<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>>;
        nonce: z.ZodOptional<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>>;
        sighash: z.ZodOptional<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>>;
        txhex: z.ZodOptional<z.ZodEffects<z.ZodString, string, string>>;
        taptweak: z.ZodOptional<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>>;
    }, "strip", z.ZodTypeAny, {
        secret: string;
        pubkey?: string | undefined;
        nonce?: string | undefined;
        sighash?: string | undefined;
        txhex?: string | undefined;
        taptweak?: string | undefined;
    }, {
        secret: string;
        pubkey?: string | undefined;
        nonce?: string | undefined;
        sighash?: string | undefined;
        txhex?: string | undefined;
        taptweak?: string | undefined;
    }>;
    signatures: z.ZodArray<z.ZodObject<{
        hash: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
        psig: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
        pubkey: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
    }, "strip", z.ZodTypeAny, {
        pubkey: string;
        hash: string;
        psig: string;
    }, {
        pubkey: string;
        hash: string;
        psig: string;
    }>, "many">;
    transactions: z.ZodArray<z.ZodObject<{
        confirmed: z.ZodBoolean;
        type: z.ZodEnum<["claim", "deposit", "refund", "settlement"]>;
        txid: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
        txhex: z.ZodEffects<z.ZodString, string, string>;
        updated_at: z.ZodDate;
    }, "strip", z.ZodTypeAny, {
        type: "refund" | "claim" | "deposit" | "settlement";
        txid: string;
        txhex: string;
        confirmed: boolean;
        updated_at: Date;
    }, {
        type: "refund" | "claim" | "deposit" | "settlement";
        txid: string;
        txhex: string;
        confirmed: boolean;
        updated_at: Date;
    }>, "many">;
}, "strip", z.ZodTypeAny, {
    status: "draft" | "published" | "active" | "disputed" | "closed";
    updated_at: Date;
    contract_id: string;
    members: string[];
    revision: number;
    created_at: Date;
    claims: {
        pubkey: string;
        address: string;
        nonce: string;
        script: string[];
    }[];
    deposits: {
        value: bigint;
        txid: string;
        vout: number;
    }[];
    details: {
        value: bigint;
        admin: string;
        agent: string;
        refund: string;
        expiration: number;
        title: string;
        description?: string | undefined;
        terms?: string | undefined;
    };
    endorsements: {
        pubkey: string;
        hash: string;
        signature: string;
    }[];
    fees: {
        pubkey: string;
        value: bigint;
        address: string;
        script: string[];
    }[];
    meta: {
        block_id: string;
        open_txid?: string | undefined;
        close_txid?: string | undefined;
    };
    payments: {
        pubkey: string;
        value: bigint;
        address: string;
        script: string[];
    }[];
    profiles: {
        pubkey: string;
        nonce: string;
        alias: string;
        tags: [string, string | number | boolean | null][];
    }[];
    records: {
        pubkey: string;
        label: string;
        content: string;
    }[];
    scripts: {
        pubkey: string;
        script: string[];
        label: string;
    }[];
    session: {
        secret: string;
        pubkey?: string | undefined;
        nonce?: string | undefined;
        sighash?: string | undefined;
        txhex?: string | undefined;
        taptweak?: string | undefined;
    };
    signatures: {
        pubkey: string;
        hash: string;
        psig: string;
    }[];
    transactions: {
        type: "refund" | "claim" | "deposit" | "settlement";
        txid: string;
        txhex: string;
        confirmed: boolean;
        updated_at: Date;
    }[];
}, {
    status: "draft" | "published" | "active" | "disputed" | "closed";
    updated_at: Date;
    contract_id: string;
    members: string[];
    revision: number;
    created_at: Date;
    claims: {
        pubkey: string;
        address: string;
        nonce: string;
        script: string[];
    }[];
    deposits: {
        value: bigint;
        txid: string;
        vout: number;
    }[];
    details: {
        value: bigint;
        admin: string;
        agent: string;
        refund: string;
        expiration: number;
        title: string;
        description?: string | undefined;
        terms?: string | undefined;
    };
    endorsements: {
        pubkey: string;
        hash: string;
        signature: string;
    }[];
    fees: {
        pubkey: string;
        value: bigint;
        address: string;
        script: string[];
    }[];
    meta: {
        block_id: string;
        open_txid?: string | undefined;
        close_txid?: string | undefined;
    };
    payments: {
        pubkey: string;
        value: bigint;
        address: string;
        script: string[];
    }[];
    profiles: {
        pubkey: string;
        nonce: string;
        alias: string;
        tags: [string, string | number | boolean | null][];
    }[];
    records: {
        pubkey: string;
        label: string;
        content: string;
    }[];
    scripts: {
        pubkey: string;
        script: string[];
        label: string;
    }[];
    session: {
        secret: string;
        pubkey?: string | undefined;
        nonce?: string | undefined;
        sighash?: string | undefined;
        txhex?: string | undefined;
        taptweak?: string | undefined;
    };
    signatures: {
        pubkey: string;
        hash: string;
        psig: string;
    }[];
    transactions: {
        type: "refund" | "claim" | "deposit" | "settlement";
        txid: string;
        txhex: string;
        confirmed: boolean;
        updated_at: Date;
    }[];
}>;
export declare const ContractSchema: {
    create: z.ZodObject<{
        value: z.ZodBigInt;
        agent: z.ZodOptional<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>>;
        refund: z.ZodString;
        expiration: z.ZodDefault<z.ZodNumber>;
        description: z.ZodOptional<z.ZodString>;
        terms: z.ZodOptional<z.ZodString>;
        title: z.ZodString;
        private: z.ZodDefault<z.ZodBoolean>;
        claims: z.ZodOptional<z.ZodArray<z.ZodObject<{
            address: z.ZodString;
            nonce: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
        }, "strip", z.ZodTypeAny, {
            address: string;
            nonce: string;
        }, {
            address: string;
            nonce: string;
        }>, "many">>;
        payments: z.ZodOptional<z.ZodArray<z.ZodObject<{
            address: z.ZodString;
            value: z.ZodBigInt;
        }, "strip", z.ZodTypeAny, {
            value: bigint;
            address: string;
        }, {
            value: bigint;
            address: string;
        }>, "many">>;
        profile: z.ZodOptional<z.ZodObject<{
            alias: z.ZodString;
            nonce: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
            tags: z.ZodArray<z.ZodTuple<[z.ZodString, z.ZodUnion<[z.ZodString, z.ZodNumber, z.ZodBoolean, z.ZodNull]>], null>, "many">;
        }, "strip", z.ZodTypeAny, {
            nonce: string;
            alias: string;
            tags: [string, string | number | boolean | null][];
        }, {
            nonce: string;
            alias: string;
            tags: [string, string | number | boolean | null][];
        }>>;
        records: z.ZodOptional<z.ZodArray<z.ZodObject<{
            label: z.ZodString;
            content: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            label: string;
            content: string;
        }, {
            label: string;
            content: string;
        }>, "many">>;
        scripts: z.ZodOptional<z.ZodArray<z.ZodObject<{
            label: z.ZodString;
            script: z.ZodArray<z.ZodString, "many">;
        }, "strip", z.ZodTypeAny, {
            script: string[];
            label: string;
        }, {
            script: string[];
            label: string;
        }>, "many">>;
    }, "strip", z.ZodTypeAny, {
        value: bigint;
        refund: string;
        expiration: number;
        title: string;
        private: boolean;
        agent?: string | undefined;
        description?: string | undefined;
        terms?: string | undefined;
        claims?: {
            address: string;
            nonce: string;
        }[] | undefined;
        payments?: {
            value: bigint;
            address: string;
        }[] | undefined;
        profile?: {
            nonce: string;
            alias: string;
            tags: [string, string | number | boolean | null][];
        } | undefined;
        records?: {
            label: string;
            content: string;
        }[] | undefined;
        scripts?: {
            script: string[];
            label: string;
        }[] | undefined;
    }, {
        value: bigint;
        refund: string;
        title: string;
        agent?: string | undefined;
        expiration?: number | undefined;
        description?: string | undefined;
        terms?: string | undefined;
        private?: boolean | undefined;
        claims?: {
            address: string;
            nonce: string;
        }[] | undefined;
        payments?: {
            value: bigint;
            address: string;
        }[] | undefined;
        profile?: {
            nonce: string;
            alias: string;
            tags: [string, string | number | boolean | null][];
        } | undefined;
        records?: {
            label: string;
            content: string;
        }[] | undefined;
        scripts?: {
            script: string[];
            label: string;
        }[] | undefined;
    }>;
    data: z.ZodObject<{
        contract_id: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
        members: z.ZodArray<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, "many">;
        status: z.ZodEnum<["draft", "published", "active", "disputed", "closed"]>;
        revision: z.ZodNumber;
        created_at: z.ZodDate;
        updated_at: z.ZodDate;
        claims: z.ZodArray<z.ZodObject<{
            address: z.ZodString;
            nonce: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
            pubkey: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
            script: z.ZodArray<z.ZodString, "many">;
        }, "strip", z.ZodTypeAny, {
            pubkey: string;
            address: string;
            nonce: string;
            script: string[];
        }, {
            pubkey: string;
            address: string;
            nonce: string;
            script: string[];
        }>, "many">;
        deposits: z.ZodArray<z.ZodObject<{
            txid: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
            vout: z.ZodNumber;
            value: z.ZodBigInt;
        }, "strip", z.ZodTypeAny, {
            value: bigint;
            txid: string;
            vout: number;
        }, {
            value: bigint;
            txid: string;
            vout: number;
        }>, "many">;
        details: z.ZodObject<{
            admin: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
            agent: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
            refund: z.ZodString;
            expiration: z.ZodNumber;
            description: z.ZodOptional<z.ZodString>;
            terms: z.ZodOptional<z.ZodString>;
            title: z.ZodString;
            value: z.ZodBigInt;
        }, "strip", z.ZodTypeAny, {
            value: bigint;
            admin: string;
            agent: string;
            refund: string;
            expiration: number;
            title: string;
            description?: string | undefined;
            terms?: string | undefined;
        }, {
            value: bigint;
            admin: string;
            agent: string;
            refund: string;
            expiration: number;
            title: string;
            description?: string | undefined;
            terms?: string | undefined;
        }>;
        endorsements: z.ZodArray<z.ZodObject<{
            hash: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
            signature: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
            pubkey: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
        }, "strip", z.ZodTypeAny, {
            pubkey: string;
            hash: string;
            signature: string;
        }, {
            pubkey: string;
            hash: string;
            signature: string;
        }>, "many">;
        fees: z.ZodArray<z.ZodObject<{
            value: z.ZodBigInt;
            address: z.ZodString;
            pubkey: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
            script: z.ZodArray<z.ZodString, "many">;
        }, "strip", z.ZodTypeAny, {
            pubkey: string;
            value: bigint;
            address: string;
            script: string[];
        }, {
            pubkey: string;
            value: bigint;
            address: string;
            script: string[];
        }>, "many">;
        meta: z.ZodObject<{
            block_id: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
            open_txid: z.ZodOptional<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>>;
            close_txid: z.ZodOptional<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>>;
        }, "strip", z.ZodTypeAny, {
            block_id: string;
            open_txid?: string | undefined;
            close_txid?: string | undefined;
        }, {
            block_id: string;
            open_txid?: string | undefined;
            close_txid?: string | undefined;
        }>;
        payments: z.ZodArray<z.ZodObject<{
            value: z.ZodBigInt;
            address: z.ZodString;
            pubkey: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
            script: z.ZodArray<z.ZodString, "many">;
        }, "strip", z.ZodTypeAny, {
            pubkey: string;
            value: bigint;
            address: string;
            script: string[];
        }, {
            pubkey: string;
            value: bigint;
            address: string;
            script: string[];
        }>, "many">;
        profiles: z.ZodArray<z.ZodObject<{
            nonce: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
            alias: z.ZodString;
            tags: z.ZodArray<z.ZodTuple<[z.ZodString, z.ZodUnion<[z.ZodString, z.ZodNumber, z.ZodBoolean, z.ZodNull]>], null>, "many">;
            pubkey: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
        }, "strip", z.ZodTypeAny, {
            pubkey: string;
            nonce: string;
            alias: string;
            tags: [string, string | number | boolean | null][];
        }, {
            pubkey: string;
            nonce: string;
            alias: string;
            tags: [string, string | number | boolean | null][];
        }>, "many">;
        records: z.ZodArray<z.ZodObject<{
            label: z.ZodString;
            content: z.ZodString;
            pubkey: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
        }, "strip", z.ZodTypeAny, {
            pubkey: string;
            label: string;
            content: string;
        }, {
            pubkey: string;
            label: string;
            content: string;
        }>, "many">;
        scripts: z.ZodArray<z.ZodObject<{
            script: z.ZodArray<z.ZodString, "many">;
            label: z.ZodString;
            pubkey: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
        }, "strip", z.ZodTypeAny, {
            pubkey: string;
            script: string[];
            label: string;
        }, {
            pubkey: string;
            script: string[];
            label: string;
        }>, "many">;
        session: z.ZodObject<{
            secret: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
            pubkey: z.ZodOptional<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>>;
            nonce: z.ZodOptional<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>>;
            sighash: z.ZodOptional<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>>;
            txhex: z.ZodOptional<z.ZodEffects<z.ZodString, string, string>>;
            taptweak: z.ZodOptional<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>>;
        }, "strip", z.ZodTypeAny, {
            secret: string;
            pubkey?: string | undefined;
            nonce?: string | undefined;
            sighash?: string | undefined;
            txhex?: string | undefined;
            taptweak?: string | undefined;
        }, {
            secret: string;
            pubkey?: string | undefined;
            nonce?: string | undefined;
            sighash?: string | undefined;
            txhex?: string | undefined;
            taptweak?: string | undefined;
        }>;
        signatures: z.ZodArray<z.ZodObject<{
            hash: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
            psig: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
            pubkey: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
        }, "strip", z.ZodTypeAny, {
            pubkey: string;
            hash: string;
            psig: string;
        }, {
            pubkey: string;
            hash: string;
            psig: string;
        }>, "many">;
        transactions: z.ZodArray<z.ZodObject<{
            confirmed: z.ZodBoolean;
            type: z.ZodEnum<["claim", "deposit", "refund", "settlement"]>;
            txid: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
            txhex: z.ZodEffects<z.ZodString, string, string>;
            updated_at: z.ZodDate;
        }, "strip", z.ZodTypeAny, {
            type: "refund" | "claim" | "deposit" | "settlement";
            txid: string;
            txhex: string;
            confirmed: boolean;
            updated_at: Date;
        }, {
            type: "refund" | "claim" | "deposit" | "settlement";
            txid: string;
            txhex: string;
            confirmed: boolean;
            updated_at: Date;
        }>, "many">;
    }, "strip", z.ZodTypeAny, {
        status: "draft" | "published" | "active" | "disputed" | "closed";
        updated_at: Date;
        contract_id: string;
        members: string[];
        revision: number;
        created_at: Date;
        claims: {
            pubkey: string;
            address: string;
            nonce: string;
            script: string[];
        }[];
        deposits: {
            value: bigint;
            txid: string;
            vout: number;
        }[];
        details: {
            value: bigint;
            admin: string;
            agent: string;
            refund: string;
            expiration: number;
            title: string;
            description?: string | undefined;
            terms?: string | undefined;
        };
        endorsements: {
            pubkey: string;
            hash: string;
            signature: string;
        }[];
        fees: {
            pubkey: string;
            value: bigint;
            address: string;
            script: string[];
        }[];
        meta: {
            block_id: string;
            open_txid?: string | undefined;
            close_txid?: string | undefined;
        };
        payments: {
            pubkey: string;
            value: bigint;
            address: string;
            script: string[];
        }[];
        profiles: {
            pubkey: string;
            nonce: string;
            alias: string;
            tags: [string, string | number | boolean | null][];
        }[];
        records: {
            pubkey: string;
            label: string;
            content: string;
        }[];
        scripts: {
            pubkey: string;
            script: string[];
            label: string;
        }[];
        session: {
            secret: string;
            pubkey?: string | undefined;
            nonce?: string | undefined;
            sighash?: string | undefined;
            txhex?: string | undefined;
            taptweak?: string | undefined;
        };
        signatures: {
            pubkey: string;
            hash: string;
            psig: string;
        }[];
        transactions: {
            type: "refund" | "claim" | "deposit" | "settlement";
            txid: string;
            txhex: string;
            confirmed: boolean;
            updated_at: Date;
        }[];
    }, {
        status: "draft" | "published" | "active" | "disputed" | "closed";
        updated_at: Date;
        contract_id: string;
        members: string[];
        revision: number;
        created_at: Date;
        claims: {
            pubkey: string;
            address: string;
            nonce: string;
            script: string[];
        }[];
        deposits: {
            value: bigint;
            txid: string;
            vout: number;
        }[];
        details: {
            value: bigint;
            admin: string;
            agent: string;
            refund: string;
            expiration: number;
            title: string;
            description?: string | undefined;
            terms?: string | undefined;
        };
        endorsements: {
            pubkey: string;
            hash: string;
            signature: string;
        }[];
        fees: {
            pubkey: string;
            value: bigint;
            address: string;
            script: string[];
        }[];
        meta: {
            block_id: string;
            open_txid?: string | undefined;
            close_txid?: string | undefined;
        };
        payments: {
            pubkey: string;
            value: bigint;
            address: string;
            script: string[];
        }[];
        profiles: {
            pubkey: string;
            nonce: string;
            alias: string;
            tags: [string, string | number | boolean | null][];
        }[];
        records: {
            pubkey: string;
            label: string;
            content: string;
        }[];
        scripts: {
            pubkey: string;
            script: string[];
            label: string;
        }[];
        session: {
            secret: string;
            pubkey?: string | undefined;
            nonce?: string | undefined;
            sighash?: string | undefined;
            txhex?: string | undefined;
            taptweak?: string | undefined;
        };
        signatures: {
            pubkey: string;
            hash: string;
            psig: string;
        }[];
        transactions: {
            type: "refund" | "claim" | "deposit" | "settlement";
            txid: string;
            txhex: string;
            confirmed: boolean;
            updated_at: Date;
        }[];
    }>;
    members: z.ZodArray<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, "many">;
};
export {};
//# sourceMappingURL=contract.d.ts.map